pub struct NonNullSendPtr<T>(NonNull<T>);
A newtype of NonNull that’s unsafely marked as Send and Sync. Use at your own discretion.

Tuple Fields

0: NonNull<T>

Implementations

source

impl<T> NonNullSendPtr<T>

source

pub fn as_ptr(opt_self: Option<Self>) -> *const T

source

pub fn as_sendptr(opt_self: Option<Self>) -> SendPtr<T>

Methods from Deref<Target = NonNull<T>>

1.25.0 · source

pub unsafe fn as_ref<'a>(&self) -> &'a T

Returns a shared reference to the value. If the value may be uninitialized, as_uninit_ref must be used instead.

For the mutable counterpart see as_mut.

Safety

When calling this method, you have to ensure that all of the following is true:

  • The pointer must be properly aligned.

  • It must be “dereferenceable” in the sense defined in the module documentation.

  • The pointer must point to an initialized instance of T.

  • You must enforce Rust’s aliasing rules, since the returned lifetime 'a is arbitrarily chosen and does not necessarily reflect the actual lifetime of the data. In particular, while this reference exists, the memory the pointer points to must not get mutated (except inside UnsafeCell).

This applies even if the result of this method is unused! (The part about being initialized is not yet fully decided, but until it is, the only safe approach is to ensure that they are indeed initialized.)

Examples
use std::ptr::NonNull;

let mut x = 0u32;
let ptr = NonNull::new(&mut x as *mut _).expect("ptr is null!");

let ref_x = unsafe { ptr.as_ref() };
println!("{ref_x}");